@@ -642,7 +642,8 @@ class NaPoleonXConnector(object):
     def get_signal_dataframe(self, productCodes, minDate, maxDate, last_only = True):
         minTs = dt.strptime(minDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T00:00:00'
         maxTs = dt.strptime(maxDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T23:59:59'
-        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, last_only)['data'])
+        result = self.get_signal_data(productCodes, minTs, maxTs, last_only)
+        signals_df = pd.DataFrame(result['data'])
         return signals_df
 
     def get_underlyings(self, productCode):
