@@ -32,7 +32,13 @@ class AbstractRunner(ABC):
         pass
 
 class SimpleSignalRunner(AbstractRunner):
+
     def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator):
+        try:
+            self.mightBreakRunTrial(saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator)
+        except Exception as e:
+            print(f'trouble {e} with run {(saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator)}')
+    def mightBreakRunTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator):
         saving_key, idios = saver.create_saving_key(seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator)
         check_run_existence, table_number = saver.checkRunExistence(saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(saving_key)
