@@ -101,7 +101,7 @@ def plot_regime_close(data_df):
 
 
 
-def plot_multiple_time_series(data_df, split =False, logy = True):
+def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strategy performances', height=600 ,width=1600):
     if split:
         fig = make_subplots(rows=1, cols=len(data_df.columns))
         constituents = [col for col in data_df.columns if col not in ['date','Date']]
@@ -117,7 +117,7 @@ def plot_multiple_time_series(data_df, split =False, logy = True):
                 fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=counter)
             counter = counter+1
 
-        fig.update_layout(height=600, width=1600, title_text="Strategy performances",showlegend=True)
+        fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
         fig.update_xaxes(rangeslider_visible=True)
         return fig
     else:
@@ -133,7 +133,7 @@ def plot_multiple_time_series(data_df, split =False, logy = True):
 
         if logy:
             fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=1)
-        fig.update_layout(height=600, width=1600, title_text="Strategy performances",showlegend=True)
+        fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
         fig.update_xaxes(rangeslider_visible=True)
         return fig
 
