@@ -87,6 +87,51 @@ def generate_fin_diffs(instantaneous_slope_fin_diff_hs, rolling_windows, thresho
                     parameters.append((fin_h,rolling_window,threshold,signal_vol_window))
     return parameters
 
+def generate_fin_diffs_slope_double(instantaneous_slope_fin_diff_hs, slope_rolling_windows, second_rolling_windows, rolling_windows, slope_thresholds, second_slope_thresholds, thresholds, signal_vol_windows):
+    parameters = []
+    for fin_h in instantaneous_slope_fin_diff_hs:
+        for rolling_window in rolling_windows:
+            for threshold in thresholds:
+                for slope_threshold in slope_thresholds:
+                    for second_slope_threshold in second_slope_thresholds:
+                        for signal_vol_window in signal_vol_windows:
+                            for slope_rolling_window in slope_rolling_windows:
+                                for second_rolling_window in second_rolling_windows:
+                                    parameters.append((fin_h,slope_rolling_window, second_rolling_window,rolling_window,slope_threshold, second_slope_threshold, threshold,signal_vol_window))
+    return parameters
+
+def generate_rolling_fin_diffs_slope(zscore_windows, instantaneous_slope_fin_diff_hs, slope_rolling_windows, second_rolling_windows, rolling_windows, slope_thresholds,):
+    parameters = []
+    for zscore_window in zscore_windows:
+        for fin_h in instantaneous_slope_fin_diff_hs:
+            for rolling_window in rolling_windows:
+                for slope_threshold in slope_thresholds:
+                    for slope_rolling_window in slope_rolling_windows:
+                        for second_rolling_window in second_rolling_windows:
+                            parameters.append((zscore_window, fin_h,slope_rolling_window, second_rolling_window,rolling_window,slope_threshold))
+    return parameters
+
+def generate_fin_diffs_slope(instantaneous_slope_fin_diff_hs, slope_rolling_windows, second_rolling_windows, rolling_windows, slope_thresholds,):
+    parameters = []
+    for fin_h in instantaneous_slope_fin_diff_hs:
+        for rolling_window in rolling_windows:
+            for slope_threshold in slope_thresholds:
+                for slope_rolling_window in slope_rolling_windows:
+                    for second_rolling_window in second_rolling_windows:
+                        parameters.append((fin_h,slope_rolling_window, second_rolling_window,rolling_window,slope_threshold))
+    return parameters
+
+def generate_fin_diffs_slope_zscore(instantaneous_slope_fin_diff_hs, zscore_windows, rolling_windows, slope_thresholds, thresholds, signal_vol_windows):
+    parameters = []
+    for fin_h in instantaneous_slope_fin_diff_hs:
+        for zscore_window in zscore_windows:
+            for rolling_window in rolling_windows:
+                for threshold in thresholds:
+                    for slope_threshold in slope_thresholds:
+                        for signal_vol_window in signal_vol_windows:
+                            parameters.append((fin_h,zscore_window,rolling_window,slope_threshold, threshold,signal_vol_window))
+    return parameters
+
 def generate_fin_diffs_advanced(instantaneous_slope_fin_diff_hs, rolling_windows, thresholds, signal_vol_windows, slope_windows, second_rolling_windows):
     parameters = []
     for fin_h in instantaneous_slope_fin_diff_hs:
