@@ -192,6 +192,18 @@ def f_sharpe_signals_mix(data, w, display_threshold = 0.99, period = 252):
     return -sharpe_strat
 
 
+@njit()
+def numba_rolling_zscore(signal_np_array, roll_size, skipping_point=5):
+    me_zscore_expanding_array = np.zeros(signal_np_array.shape)
+    for i in range(len(signal_np_array)):
+        if i <= skipping_point:
+            me_zscore_expanding_array[i] = signal_np_array[i]
+        else :
+            std_dev = max(signal_np_array[max(i-roll_size,0):i].std(), 1e-4)
+            me_zscore_expanding_array[i] = (signal_np_array[i] - signal_np_array[max(i-roll_size,0):i].mean())/std_dev
+    return me_zscore_expanding_array
+
+
 @njit()
 def numba_expanding_zscore(signal_np_array, skipping_point):
     me_zscore_expanding_array = np.zeros(signal_np_array.shape)
